# revolt

[![Codecov](https://img.shields.io/codecov/c/github/d42-schemas/revolt/master.svg?style=flat-square)](https://codecov.io/gh/d42-schemas/revolt)
[![PyPI](https://img.shields.io/pypi/v/revolt.svg?style=flat-square)](https://pypi.python.org/pypi/revolt/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/revolt?style=flat-square)](https://pypi.python.org/pypi/revolt/)
[![Python Version](https://img.shields.io/pypi/pyversions/revolt.svg?style=flat-square)](https://pypi.python.org/pypi/revolt/)

`revolt` is a package designed to substitute values based on the [district42](https://github.com/d42-schemas/district42) schemas. It provides a simple and flexible way to substitute values in complex data structures.

This package is part of the [d42 package](https://pypi.org/project/d42/). For a quick-start guide and detailed documentation, please visit the official documentation at [d42.sh/docs/quick-start](https://d42.sh/docs/quick-start)
